/*
 * Copyright (c) 2006, TopCoder, Inc. All rights reserved.
 */
using NAnt.Core;
using System;

namespace TopCoder.Test.Framework
{
    /// <summary>
    /// <p>
    /// This exception is derived from BuildException.
    /// It is thrown by the ServerAppTestTask when any exceptions are caught when executing the task.
    /// </p>
    /// </summary>
    ///
    /// <author>real_vg</author>
    /// <author>TCSDEVELOPER</author>
    /// <version>1.0</version>
    /// <copyright>Copyright (c) 2006, TopCoder, Inc. All rights reserved.</copyright>
    public class ServerTaskException : BuildException
    {

        /// <summary>
        /// <p>
        /// This variable stores the array of "inner" exceptions.
        /// These are the cause exceptions of this exception.
        /// Is initialized in constructor, can be null.
        /// If is not null, elements cannot be null.
        /// Is immutable.
        /// </p>
        /// </summary>
        private readonly Exception[] innerExceptions;

        /// <summary>
        /// <p>
        /// This property is used to read the "innerExceptions" variable.
        /// The "innerExceptions" variable stores the array of "inner" exceptions.
        /// These are the cause exceptions of this exception.
        /// </p>
        /// </summary>
        /// <value>The inner exceptions.</value>
        public Exception[] InnerExceptions
        {
            get
            {
                return innerExceptions;
            }
        }

        /// <summary>
        /// <p>
        /// Constructs an exception with the message string and inner exceptions.
        /// </p>
        /// </summary>
        ///
        /// <param name="message">the human-readable error message string, can be null</param>
        /// <param name="innerExceptions">the array of exception which caused this exception, can be null</param>
        public ServerTaskException(string message, Exception[] innerExceptions)
            : base(message, innerExceptions != null ? innerExceptions[0] : null)
        {
            this.innerExceptions = innerExceptions;
        }
    }

}
