/*
 * Copyright (c) 2006, TopCoder, Inc. All rights reserved.
 */
using System;
using NUnit.Framework;

namespace TopCoder.Test.Framework.Servers
{

    /// <summary>
    /// Unit test class for <c>ServerException</c> class.
    /// </summary>
    ///
    /// <author>TCSDEVELOPER</author>
    /// <version>1.0</version>
    /// <copyright>Copyright (c) 2006, TopCoder, Inc. All rights reserved.</copyright>
    [TestFixture]
    public class ServerExceptionTest
    {

        /// <summary>
        /// Represents the detail error message.
        /// </summary>
        private const string MESSAGE = "Error msg";

        /// <summary>
        /// Represents the original cause of the error.
        /// </summary>
        private static readonly Exception CAUSE = new Exception();

        /// <summary>
        /// Tests inheritance of <c>ServerException</c> class.
        /// The <c>ServerException</c> class should be inherited from <c>ApplicationException</c> class.
        /// </summary>
        [Test]
        public void TestServerExceptionAccuracyInherit1()
        {
            Assert.IsTrue((object)new ServerException(MESSAGE) is ApplicationException,
                "ServerException should be inherited from ApplicationException.");
        }

        /// <summary>
        /// Tests inheritance of <c>ServerException</c> class.
        /// The <c>ServerException</c> class should be inherited from <c>ApplicationException</c> class.
        /// </summary>
        [Test]
        public void TestServerExceptionAccuracyInherit2()
        {
            Assert.IsTrue((object)new ServerException(MESSAGE, CAUSE) is ApplicationException,
                "ServerException should be inherited from ApplicationException.");
        }

        /// <summary>
        /// Tests accuracy of constructor of <c>ServerException(string)</c>.
        /// The variable field should be set correctly.
        /// </summary>
        [Test]
        public void TestServerExceptionStringAccuracy1()
        {
            ServerException exception = new ServerException(MESSAGE);

            Assert.AreEqual(MESSAGE, exception.Message, "The detail message should be the same as in argument.");
        }

        /// <summary>
        /// Tests accuracy of constructor of <c>ServerException(string)</c>.
        /// Null message parameter should be accepted.
        /// </summary>
        [Test]
        public void TestServerExceptionStringAccuracy2()
        {
            ServerException exception = new ServerException(null);

            Assert.IsNotNull(exception, "The newly created exception should not be null.");
        }

        /// <summary>
        /// Tests accuracy of constructor of <c>ServerException(string, Exception)</c>.
        /// The variable field should be set correctly.
        /// </summary>
        [Test]
        public void TestServerExceptionStringExceptionAccuracy()
        {
            ServerException exception = new ServerException(MESSAGE, CAUSE);

            Assert.AreEqual(MESSAGE, exception.Message, "The detail message should be the same as in argument.");
            Assert.AreEqual(CAUSE, exception.InnerException, "The cause should be the same as in argument.");
        }

        /// <summary>
        /// Tests accuracy of constructor of <c>ServerException(string, Exception)</c>.
        /// Null message parameter should be accepted.
        /// The inner exception variable field should be set correctly.
        /// </summary>
        [Test]
        public void TestServerExceptionStringExceptionAccuracyNullStringParam()
        {
            ServerException exception = new ServerException(null, CAUSE);

            Assert.IsNotNull(exception, "The newly created exception should not be null.");
            Assert.AreEqual(CAUSE, exception.InnerException, "The cause should be the same as in argument.");
        }

        /// <summary>
        /// Tests accuracy of constructor of <c>ServerException(string, Exception)</c>.
        /// The message variable field should be set correctly.
        /// Null inner exception parameter should be accepted.
        /// </summary>
        [Test]
        public void TestServerExceptionStringExceptionAccuracyNullExceptionParam()
        {
            ServerException exception = new ServerException(MESSAGE, null);

            Assert.IsNotNull(exception, "The newly created exception should not be null.");
            Assert.AreEqual(MESSAGE, exception.Message, "The detail message should be the same as in argument.");
        }

        /// <summary>
        /// Tests accuracy of constructor of <c>ServerException(string, Exception)</c>.
        /// Null message parameter should be accepted.
        /// Null inner exception parameter should be accepted.
        /// </summary>
        [Test]
        public void TestServerExceptionStringExceptionAccuracyNullStringAndExceptionParam()
        {
            ServerException exception = new ServerException(null, null);

            Assert.IsNotNull(exception, "The newly created exception should not be null.");
        }
    }
}
