/*
 * Copyright (c) 2006, TopCoder, Inc. All rights reserved.
 */
using System;
using NUnit.Framework;
using NAnt.Core.Types;

namespace TopCoder.Test.Framework.Servers
{

    /// <summary>
    /// Unit test class for <c>Server</c> class.
    /// </summary>
    ///
    /// <author>TCSDEVELOPER</author>
    /// <version>1.0</version>
    /// <copyright>Copyright (c) 2006, TopCoder, Inc. All rights reserved.</copyright>
    [TestFixture]
    public class ServerTest
    {

        /// <summary>
        /// Private <c>MockServer</c> variable used for test.
        /// </summary>
        private MockServer server;

        /// <summary>
        /// Sets up the test environment. A valid <c>MockServer</c> object is created.
        /// </summary>
        [SetUp]
        protected void SetUp()
        {
            server = new MockServer();
        }

        /// <summary>
        /// Tests accuracy of constructor <c>Server()</c> of <c>Server</c> class.
        /// The fields should be initialized properly.
        /// </summary>
        [Test]
        public void TestServerAccuracy()
        {
            Assert.IsTrue(server.StartServer, "StartServer should be set as true.");
            Assert.IsTrue(server.InitServer, "InitServer should be set as true.");
            Assert.IsNull(server.Options, "Options should be set as null.");
            Assert.IsNull(server.Credentials, "Credentials should be set as null.");
            Assert.IsNull(server.SourceFiles, "SourceFiles should be set as null.");
        }

        /// <summary>
        /// Tests accuracy of constant <c>TIMEOUT</c> of <c>Server</c> class.
        /// The fields should be initialized properly.
        /// </summary>
        [Test]
        public void TestConstantTimeoutAccuracy()
        {
            Assert.AreEqual("timeout", Server.TIMEOUT, "TIMEOUT constant should be correct.");
        }

        /// <summary>
        /// Tests accuracy of constant <c>ADDRESS</c> of <c>Server</c> class.
        /// The fields should be initialized properly.
        /// </summary>
        [Test]
        public void TestConstantAddressAccuracy()
        {
            Assert.AreEqual("address", Server.ADDRESS, "ADDRESS constant should be correct.");
        }

        /// <summary>
        /// Tests accuracy of constant <c>PORT</c> of <c>Server</c> class.
        /// The fields should be initialized properly.
        /// </summary>
        [Test]
        public void TestConstantPortAccuracy()
        {
            Assert.AreEqual("port", Server.PORT, "PORT constant should be correct.");
        }

        /// <summary>
        /// Tests accuracy of <c>StartServer</c> getter property of <c>Server</c> class.
        /// The field value should be gotten correctly.
        /// </summary>
        [Test]
        public void TestStartServerGetterAccuracyTrue()
        {
            Assert.IsTrue(server.StartServer, "StartServer should be true.");
        }

        /// <summary>
        /// Tests accuracy of <c>StartServer</c> getter property of <c>Server</c> class.
        /// The field value should be gotten correctly.
        /// </summary>
        [Test]
        public void TestStartServerGetterAccuracyFalse()
        {
            server.StartServer = false;
            Assert.IsFalse(server.StartServer, "StartServer should be false.");
        }

        /// <summary>
        /// Tests accuracy of <c>StartServer</c> setter property of <c>Server</c> class.
        /// The field value should be set correctly.
        /// </summary>
        [Test]
        public void TestStartServerSetterAccuracyFalse()
        {
            server.StartServer = false;
            Assert.IsFalse(server.StartServer, "StartServer should be set as false.");
        }

        /// <summary>
        /// Tests accuracy of <c>StartServer</c> setter property of <c>Server</c> class.
        /// The field value should be set correctly.
        /// </summary>
        [Test]
        public void TestStartServerSetterAccuracyTrue()
        {
            server.StartServer = true;
            Assert.IsTrue(server.StartServer, "StartServer should be set as true.");
        }


        /// <summary>
        /// Tests accuracy of <c>InitServer</c> getter property of <c>Server</c> class.
        /// The field value should be gotten correctly.
        /// </summary>
        [Test]
        public void TestInitServerGetterAccuracyTrue()
        {
            Assert.IsTrue(server.InitServer, "InitServer should be true.");
        }

        /// <summary>
        /// Tests accuracy of <c>InitServer</c> getter property of <c>Server</c> class.
        /// The field value should be gotten correctly.
        /// </summary>
        [Test]
        public void TestInitServerGetterAccuracyFalse()
        {
            server.InitServer = false;
            Assert.IsFalse(server.InitServer, "InitServer should be false.");
        }

        /// <summary>
        /// Tests accuracy of <c>InitServer</c> setter property of <c>Server</c> class.
        /// The field value should be set correctly.
        /// </summary>
        [Test]
        public void TestInitServerSetterAccuracyFalse()
        {
            server.InitServer = false;
            Assert.IsFalse(server.InitServer, "InitServer should be set as false.");
        }

        /// <summary>
        /// Tests accuracy of <c>InitServer</c> setter property of <c>Server</c> class.
        /// The field value should be set correctly.
        /// </summary>
        [Test]
        public void TestInitServerSetterAccuracyTrue()
        {
            server.InitServer = true;
            Assert.IsTrue(server.InitServer, "InitServer should be set as true.");
        }


        /// <summary>
        /// Tests accuracy of <c>Options</c> getter property of <c>Server</c> class.
        /// The field value should be gotten correctly.
        /// </summary>
        [Test]
        public void TestOptionsGetterAccuracyNull()
        {
            Assert.IsNull(server.Options, "Options should be null.");
        }

        /// <summary>
        /// Tests accuracy of <c>Options</c> getter property of <c>Server</c> class.
        /// The field value should be gotten correctly.
        /// </summary>
        [Test]
        public void TestOptionsGetterAccuracyNonNull()
        {
            server.Options = new OptionCollection();
            Assert.IsNotNull(server.Options, "Options should not be null.");
        }

        /// <summary>
        /// Tests accuracy of <c>Options</c> setter property of <c>Server</c> class.
        /// The field value should be set correctly.
        /// </summary>
        [Test]
        public void TestOptionsSetterAccuracyNull()
        {
            server.Options = null;
            Assert.IsNull(server.Options, "Options should be null.");
        }

        /// <summary>
        /// Tests accuracy of <c>Options</c> setter property of <c>Server</c> class.
        /// The field value should be set correctly.
        /// </summary>
        [Test]
        public void TestOptionsSetterAccuracyNonNull()
        {
            server.Options = new OptionCollection();
            Assert.IsNotNull(server.Options, "Options should not be null.");
        }


        /// <summary>
        /// Tests accuracy of <c>Credentials</c> getter property of <c>Server</c> class.
        /// The field value should be gotten correctly.
        /// </summary>
        [Test]
        public void TestCredentialsGetterAccuracyNull()
        {
            Assert.IsNull(server.Credentials, "Credentials should be null.");
        }

        /// <summary>
        /// Tests accuracy of <c>Credentials</c> getter property of <c>Server</c> class.
        /// The field value should be gotten correctly.
        /// </summary>
        [Test]
        public void TestCredentialsGetterAccuracyNonNull()
        {
            server.Credentials = new Credential();
            Assert.IsNotNull(server.Credentials, "Credentials should not be null.");
        }

        /// <summary>
        /// Tests accuracy of <c>Credentials</c> setter property of <c>Server</c> class.
        /// The field value should be set correctly.
        /// </summary>
        [Test]
        public void TestCredentialsSetterAccuracyNull()
        {
            server.Credentials = null;
            Assert.IsNull(server.Credentials, "Credentials should be null.");
        }

        /// <summary>
        /// Tests accuracy of <c>Credentials</c> setter property of <c>Server</c> class.
        /// The field value should be set correctly.
        /// </summary>
        [Test]
        public void TestCredentialsSetterAccuracyNonNull()
        {
            server.Credentials = new Credential();
            Assert.IsNotNull(server.Credentials, "Credentials should not be null.");
        }

        /// <summary>
        /// Tests accuracy of <c>SourceFiles</c> getter property of <c>Server</c> class.
        /// The field value should be gotten correctly.
        /// </summary>
        [Test]
        public void TestSourceFilesGetterAccuracyNull()
        {
            Assert.IsNull(server.SourceFiles, "SourceFiles should be null.");
        }

        /// <summary>
        /// Tests accuracy of <c>SourceFiles</c> getter property of <c>Server</c> class.
        /// The field value should be gotten correctly.
        /// </summary>
        [Test]
        public void TestSourceFilesGetterAccuracyNonNull()
        {
            server.SourceFiles = new FileSet();
            Assert.IsNotNull(server.SourceFiles, "SourceFiles should not be null.");
        }

        /// <summary>
        /// Tests accuracy of <c>SourceFiles</c> setter property of <c>Server</c> class.
        /// The field value should be set correctly.
        /// </summary>
        [Test]
        public void TestSourceFilesSetterAccuracyNull()
        {
            server.SourceFiles = null;
            Assert.IsNull(server.SourceFiles, "SourceFiles should be null.");
        }

        /// <summary>
        /// Tests accuracy of <c>SourceFiles</c> setter property of <c>Server</c> class.
        /// The field value should be set correctly.
        /// </summary>
        [Test]
        public void TestSourceFilesSetterAccuracyNonNull()
        {
            server.SourceFiles = new FileSet();
            Assert.IsNotNull(server.SourceFiles, "SourceFiles should not be null.");
        }

        /// <summary>
        /// Tests accuracy of <c>Address</c> getter property of <c>Server</c> class.
        /// The field value should be gotten correctly.
        /// </summary>
        [Test]
        public void TestAddressGetterAccuracyNull()
        {
            // set options
            OptionCollection options = new OptionCollection();
            options.Add(TestFrameworkTestHelper.CreateOption(Server.ADDRESS, null));
            server.Options = options;

            Assert.IsNull(server.Address, "Address value should be null.");
        }

        /// <summary>
        /// Tests accuracy of <c>Address</c> getter property of <c>Server</c> class.
        /// The field value should be gotten correctly.
        /// </summary>
        [Test]
        public void TestAddressGetterAccuracyNonNull()
        {
            // set options
            OptionCollection options = new OptionCollection();
            options.Add(TestFrameworkTestHelper.CreateOption(Server.ADDRESS, "address value"));
            server.Options = options;

            Assert.AreEqual("address value", server.Address, "Address value should be correct.");
        }

        /// <summary>
        /// Tests failure of <c>Address</c> getter property of <c>Server</c> class.
        /// Options field is not set will lead to failure.
        /// Expect <c>ServerException</c>.
        /// </summary>
        [Test, ExpectedException(typeof(ServerException))]
        public void TestAddressGetterFailureOptionsNotSet()
        {
            // set options
            server.Options = null;

            string temp = server.Address;
        }

        /// <summary>
        /// Tests failure of <c>Address</c> getter property of <c>Server</c> class.
        /// Option specified is not set will lead to failure.
        /// Expect <c>ServerException</c>.
        /// </summary>
        [Test, ExpectedException(typeof(ServerException))]
        public void TestAddressGetterFailureNoSpecifiedOption()
        {
            // set options
            OptionCollection options = new OptionCollection();
            options.Add(TestFrameworkTestHelper.CreateOption("notAddress", "address value"));
            server.Options = options;

            string temp = server.Address;
        }


        /// <summary>
        /// Tests accuracy of <c>Timeout</c> getter property of <c>Server</c> class.
        /// The field value should be gotten correctly.
        /// </summary>
        [Test]
        public void TestTimeoutGetterAccuracyZero()
        {
            // set options
            OptionCollection options = new OptionCollection();
            options.Add(TestFrameworkTestHelper.CreateOption(Server.TIMEOUT, "0"));
            server.Options = options;

            Assert.AreEqual(0, server.Timeout, "Timeout value should be correct.");
        }

        /// <summary>
        /// Tests accuracy of <c>Timeout</c> getter property of <c>Server</c> class.
        /// The field value should be gotten correctly.
        /// </summary>
        [Test]
        public void TestTimeoutGetterAccuracyOne()
        {
            // set options
            OptionCollection options = new OptionCollection();
            options.Add(TestFrameworkTestHelper.CreateOption(Server.TIMEOUT, "1"));
            server.Options = options;

            Assert.AreEqual(1, server.Timeout, "Timeout value should be correct.");
        }

        /// <summary>
        /// Tests accuracy of <c>Timeout</c> getter property of <c>Server</c> class.
        /// The field value should be gotten correctly.
        /// </summary>
        [Test]
        public void TestTimeoutGetterAccuracy65535()
        {
            // set options
            OptionCollection options = new OptionCollection();
            options.Add(TestFrameworkTestHelper.CreateOption(Server.TIMEOUT, "65535"));
            server.Options = options;

            Assert.AreEqual(65535, server.Timeout, "Timeout value should be correct.");
        }

        /// <summary>
        /// Tests accuracy of <c>Timeout</c> getter property of <c>Server</c> class.
        /// The field value should be gotten correctly.
        /// </summary>
        [Test]
        public void TestTimeoutGetterAccuracy65536()
        {
            // set options
            OptionCollection options = new OptionCollection();
            options.Add(TestFrameworkTestHelper.CreateOption(Server.TIMEOUT, "65536"));
            server.Options = options;

            Assert.AreEqual(65536, server.Timeout, "Timeout value should be correct.");
        }

        /// <summary>
        /// Tests accuracy of <c>Timeout</c> getter property of <c>Server</c> class.
        /// The field value should be gotten correctly.
        /// </summary>
        [Test]
        public void TestTimeoutGetterAccuracyMax()
        {
            // set options
            OptionCollection options = new OptionCollection();
            options.Add(TestFrameworkTestHelper.CreateOption(Server.TIMEOUT, Int32.MaxValue.ToString()));
            server.Options = options;

            Assert.AreEqual(Int32.MaxValue, server.Timeout, "Timeout value should be correct.");
        }

        /// <summary>
        /// Tests failure of <c>Timeout</c> getter property of <c>Server</c> class.
        /// Options field is not set will lead to failure.
        /// Expect <c>ServerException</c>.
        /// </summary>
        [Test, ExpectedException(typeof(ServerException))]
        public void TestTimeoutGetterFailureOptionsNotSet()
        {
            // set options
            server.Options = null;

            int temp = server.Timeout;
        }

        /// <summary>
        /// Tests failure of <c>Timeout</c> getter property of <c>Server</c> class.
        /// Option specified is not set will lead to failure.
        /// Expect <c>ServerException</c>.
        /// </summary>
        [Test, ExpectedException(typeof(ServerException))]
        public void TestTimeoutGetterFailureNoSpecifiedOption()
        {
            // set options
            OptionCollection options = new OptionCollection();
            options.Add(TestFrameworkTestHelper.CreateOption("notTimeout", "Timeout value"));
            server.Options = options;

            int temp = server.Timeout;
        }

        /// <summary>
        /// Tests failure of <c>Timeout</c> getter property of <c>Server</c> class.
        /// Negative option value will lead to failure.
        /// Expect <c>ServerException</c>.
        /// </summary>
        [Test, ExpectedException(typeof(ServerException))]
        public void TestTimeoutGetterFailureNegative()
        {
            // set options
            OptionCollection options = new OptionCollection();
            options.Add(TestFrameworkTestHelper.CreateOption(Server.TIMEOUT, "-1"));
            server.Options = options;

            int temp = server.Timeout;
        }

        /// <summary>
        /// Tests failure of <c>Timeout</c> getter property of <c>Server</c> class.
        /// Wrong format option value will lead to failure.
        /// Expect <c>ServerException</c>.
        /// </summary>
        [Test, ExpectedException(typeof(ServerException))]
        public void TestTimeoutGetterFailureWrongFormat()
        {
            // set options
            OptionCollection options = new OptionCollection();
            options.Add(TestFrameworkTestHelper.CreateOption(Server.TIMEOUT, "--1"));
            server.Options = options;

            int temp = server.Timeout;
        }

        /// <summary>
        /// Tests failure of <c>Timeout</c> getter property of <c>Server</c> class.
        /// Option value out of range will lead to failure.
        /// Expect <c>ServerException</c>.
        /// </summary>
        [Test, ExpectedException(typeof(ServerException))]
        public void TestTimeoutGetterFailureOverflow()
        {
            // set options
            OptionCollection options = new OptionCollection();
            options.Add(TestFrameworkTestHelper.CreateOption(Server.TIMEOUT, "2147483648"));
            server.Options = options;

            int temp = server.Timeout;
        }




        /// <summary>
        /// Tests accuracy of <c>Port</c> getter property of <c>Server</c> class.
        /// The field value should be gotten correctly.
        /// </summary>
        [Test]
        public void TestPortGetterAccuracyZero()
        {
            // set options
            OptionCollection options = new OptionCollection();
            options.Add(TestFrameworkTestHelper.CreateOption(Server.PORT, "0"));
            server.Options = options;

            Assert.AreEqual(0, server.Port, "Port value should be correct.");
        }

        /// <summary>
        /// Tests accuracy of <c>Port</c> getter property of <c>Server</c> class.
        /// The field value should be gotten correctly.
        /// </summary>
        [Test]
        public void TestPortGetterAccuracyOne()
        {
            // set options
            OptionCollection options = new OptionCollection();
            options.Add(TestFrameworkTestHelper.CreateOption(Server.PORT, "1"));
            server.Options = options;

            Assert.AreEqual(1, server.Port, "Port value should be correct.");
        }

        /// <summary>
        /// Tests accuracy of <c>Port</c> getter property of <c>Server</c> class.
        /// The field value should be gotten correctly.
        /// </summary>
        [Test]
        public void TestPortGetterAccuracy65535()
        {
            // set options
            OptionCollection options = new OptionCollection();
            options.Add(TestFrameworkTestHelper.CreateOption(Server.PORT, "65535"));
            server.Options = options;

            Assert.AreEqual(65535, server.Port, "Port value should be correct.");
        }

        /// <summary>
        /// Tests accuracy of <c>Port</c> getter property of <c>Server</c> class.
        /// Port option value should be in valid port range.
        /// Expect <c>ServerException</c>.
        /// </summary>
        [Test, ExpectedException(typeof(ServerException))]
        public void TestPortGetterFailure65536()
        {
            // set options
            OptionCollection options = new OptionCollection();
            options.Add(TestFrameworkTestHelper.CreateOption(Server.PORT, "65536"));
            server.Options = options;

            int temp = server.Port;
        }

        /// <summary>
        /// Tests accuracy of <c>Port</c> getter property of <c>Server</c> class.
        /// Port option value should be in valid port range.
        /// Expect <c>ServerException</c>.
        /// </summary>
        [Test, ExpectedException(typeof(ServerException))]
        public void TestPortGetterFailureIntMax()
        {
            // set options
            OptionCollection options = new OptionCollection();
            options.Add(TestFrameworkTestHelper.CreateOption(Server.PORT, Int32.MaxValue.ToString()));
            server.Options = options;

            int temp = server.Port;
        }

        /// <summary>
        /// Tests failure of <c>Port</c> getter property of <c>Server</c> class.
        /// Options field is not set will lead to failure.
        /// Expect <c>ServerException</c>.
        /// </summary>
        [Test, ExpectedException(typeof(ServerException))]
        public void TestPortGetterFailureOptionsNotSet()
        {
            // set options
            server.Options = null;

            int temp = server.Port;
        }

        /// <summary>
        /// Tests failure of <c>Port</c> getter property of <c>Server</c> class.
        /// Option specified is not set will lead to failure.
        /// Expect <c>ServerException</c>.
        /// </summary>
        [Test, ExpectedException(typeof(ServerException))]
        public void TestPortGetterFailureNoSpecifiedOption()
        {
            // set options
            OptionCollection options = new OptionCollection();
            options.Add(TestFrameworkTestHelper.CreateOption("notPort", "Port value"));
            server.Options = options;

            int temp = server.Port;
        }

        /// <summary>
        /// Tests failure of <c>Port</c> getter property of <c>Server</c> class.
        /// Negative option value will lead to failure.
        /// Expect <c>ServerException</c>.
        /// </summary>
        [Test, ExpectedException(typeof(ServerException))]
        public void TestPortGetterFailureNegative()
        {
            // set options
            OptionCollection options = new OptionCollection();
            options.Add(TestFrameworkTestHelper.CreateOption(Server.PORT, "-1"));
            server.Options = options;

            int temp = server.Port;
        }

        /// <summary>
        /// Tests failure of <c>Port</c> getter property of <c>Server</c> class.
        /// Wrong format option value will lead to failure.
        /// Expect <c>ServerException</c>.
        /// </summary>
        [Test, ExpectedException(typeof(ServerException))]
        public void TestPortGetterFailureWrongFormat()
        {
            // set options
            OptionCollection options = new OptionCollection();
            options.Add(TestFrameworkTestHelper.CreateOption(Server.PORT, "--1"));
            server.Options = options;

            int temp = server.Port;
        }

        /// <summary>
        /// Tests failure of <c>Port</c> getter property of <c>Server</c> class.
        /// Option value out of range will lead to failure.
        /// Expect <c>ServerException</c>.
        /// </summary>
        [Test, ExpectedException(typeof(ServerException))]
        public void TestPortGetterFailureOverflow()
        {
            // set options
            OptionCollection options = new OptionCollection();
            options.Add(TestFrameworkTestHelper.CreateOption(Server.PORT, "2147483648"));
            server.Options = options;

            int temp = server.Port;
        }

    }

}
